@@ -149,20 +149,22 @@ class TaskHub():
             if time.time() - t > self.check_gap:
                 # 加锁
                 self.get_lock()
+                try:
+                    # 输出状态
+                    status_str = "tasks: "
+                    for key, task in self.tasks.items():
+                        status_str += "{}：{}\t".format(key, task.status)
+                    makelog(status_str)
 
-                # 输出状态
-                status_str = "tasks: "
-                for key, task in self.tasks.items():
-                    status_str += "{}：{}\t".format(key, task.status)
-                makelog(status_str)
-
-                # 检查需要同步的数据
-                for key,task in self.tasks.items():
-                    if task.status == "done":
-                        # 将数据同步到后端
-                        if self.sync(task):
-                            del self.tasks[key]
-
+                    # 检查需要同步的数据
+                    for key,task in self.tasks.items():
+                        if task.status == "done":
+                            # 将数据同步到后端
+                            if self.sync(task):
+                                del self.tasks[key]
+                except:
+                    makelog("未知异常：{}".format(traceback.format_exc()),1)
+                    
                 # 释放锁
                 self.release_lock() 
                 t = time.time()
